aboutsummaryrefslogtreecommitdiff
path: root/infra/libkookie/nixpkgs/nixos/modules/programs/ssmtp.nix
diff options
context:
space:
mode:
authorMx Kookie <kookie@spacekookie.de>2020-12-09 18:55:19 +0000
committerMx Kookie <kookie@spacekookie.de>2020-12-09 18:55:19 +0000
commit80d90d9b204f7c17912740f9f414fe5d59f293ba (patch)
tree5f2065a06e724270610760d59d01c6888b375a46 /infra/libkookie/nixpkgs/nixos/modules/programs/ssmtp.nix
parent3a31a84c7d3e589035ad08499206aac44a81f424 (diff)
parent83cbad92d73216bb0d9187c56cce0b91f9121d5a (diff)
Merge commit '83cbad92d73216bb0d9187c56cce0b91f9121d5a' into main
Diffstat (limited to 'infra/libkookie/nixpkgs/nixos/modules/programs/ssmtp.nix')
-rw-r--r--infra/libkookie/nixpkgs/nixos/modules/programs/ssmtp.nix9
1 files changed, 8 insertions, 1 deletions
diff --git a/infra/libkookie/nixpkgs/nixos/modules/programs/ssmtp.nix b/infra/libkookie/nixpkgs/nixos/modules/programs/ssmtp.nix
index 15d2750c193f..1f49ddc91bb3 100644
--- a/infra/libkookie/nixpkgs/nixos/modules/programs/ssmtp.nix
+++ b/infra/libkookie/nixpkgs/nixos/modules/programs/ssmtp.nix
@@ -1,6 +1,6 @@
# Configuration for `ssmtp', a trivial mail transfer agent that can
# replace sendmail/postfix on simple systems. It delivers email
# directly to an SMTP server defined in its configuration file, wihout
# queueing mail locally.
{ config, lib, pkgs, ... }:
@@ -142,6 +142,13 @@ in
config = mkIf cfg.enable {
+ assertions = [
+ {
+ assertion = cfg.useSTARTTLS -> cfg.useTLS;
+ message = "services.ssmtp.useSTARTTLS has no effect without services.ssmtp.useTLS";
+ }
+ ];
+
services.ssmtp.settings = mkMerge [
({
MailHub = cfg.hostName;
@@ -1,6 +1,6 @@
# Configuration for `ssmtp', a trivial mail transfer agent that can
# replace sendmail/postfix on simple systems. It delivers email
-# directly to an SMTP server defined in its configuration file, wihout
+# directly to an SMTP server defined in its configuration file, without
# queueing mail locally.
{ config, lib, pkgs, ... }: